@@ -17,13 +17,13 @@
 #include "config/GOConfig.h"
 #include "control/GOEventDistributor.h"
 #include "control/GOLabelControl.h"
-#include "gui/GOGUIMouseState.h"
+#include "gui/frames/GOMainWindowData.h"
+#include "gui/panels/GOGUIMouseState.h"
 #include "loader/GOFileStore.h"
 #include "model/GOOrganModel.h"
 #include "modification/GOModificationProxy.h"
 
 #include "GOBitmapCache.h"
-#include "GOMainWindowData.h"
 #include "GOMemoryPool.h"
 #include "GOTimer.h"
 #include "GOVirtualCouplerController.h"
@@ -54,7 +54,6 @@ class GOSoundRecorder;
 typedef struct _GOHashType GOHashType;
 
 class GOOrganController : public GOEventDistributor,
-                          public GOTimer,
                           public GOOrganModel,
                           public GOModificationProxy {
 private:
@@ -73,6 +72,8 @@ private:
   GOAudioRecorder *m_AudioRecorder;
   GOMidiPlayer *m_MidiPlayer;
   GOMidiRecorder *m_MidiRecorder;
+  GOSizeKeeper m_StopWindowSizeKeeper;
+  GOTimer *m_timer;
   GOButtonControl *p_OnStateButton;
   int m_volume;
   wxString m_Temperament;
@@ -102,7 +103,7 @@ private:
   GOGUIMouseState m_MouseState;
 
   GOMemoryPool m_pool;
-  GOBitmapCache m_bitmaps;
+  GOBitmapCache *m_bitmaps;
   GOLabelControl m_PitchLabel;
   GOLabelControl m_TemperamentLabel;
   GOMainWindowData m_MainWindowData;
@@ -126,9 +127,13 @@ private:
 
 public:
   GOOrganController(
-    GOConfig &config, GOMidiDialogCreator *pMidiDialogCreator = nullptr);
+    GOConfig &config,
+    GOMidiDialogCreator *pMidiDialogCreator = nullptr,
+    bool isAppInitialized = false);
   ~GOOrganController();
 
+  GOSizeKeeper &GetStopWindowSizeKeeper() { return m_StopWindowSizeKeeper; }
+
   // Returns organ modification flag
   bool IsOrganModified() const { return m_OrganModified; }
   // Sets the organ modification flag
@@ -184,7 +189,7 @@ public:
   void AddPanel(GOGUIPanel *panel);
   GOMemoryPool &GetMemoryPool();
   GOConfig &GetSettings();
-  GOBitmapCache &GetBitmapCache();
+  GOBitmapCache &GetBitmapCache() const { return *m_bitmaps; }
   void SetTemperament(wxString name);
   wxString GetTemperament();
 
@@ -232,6 +237,11 @@ public:
   GOMidi *GetMidi();
 
   GOGUIMouseState &GetMouseState() { return m_MouseState; }
+
+  /**
+   * Return the Timer Manager for Metronome, Midi recorder, ...
+   */
+  GOTimer *GetTimer() const { return m_timer; }
 };
 
 #endif
