@@ -305,7 +305,7 @@ GOSetter::GOSetter(GOOrganController *organController)
     m_CrescendoDisplay(organController),
     m_TransposeDisplay(organController),
     m_NameDisplay(organController),
-    m_swell(*organController) {
+    m_CrescendoCtrl(*organController) {
   CreateButtons(*m_OrganController);
 
   m_buttons[ID_SETTER_PREV]->SetPreconfigIndex(0);
@@ -351,6 +351,18 @@ GOSetter::GOSetter(GOOrganController *organController)
 GOSetter::~GOSetter() {}
 
 static const wxString WX_OVERRIDE_MODE = wxT("OverrideMode");
+static const wxString WX_EMPTY_STRING = wxEmptyString;
+
+static wxString crescendo_cmb_state_name(
+  bool isOverride, uint8_t crescendoIdx) {
+  return isOverride ? WX_EMPTY_STRING
+                    : wxString::Format("crescendo-%c", 'A' + crescendoIdx);
+}
+
+wxString GOSetter::GetCrescendoCmbStateName(uint8_t crescendoIdx) const {
+  return crescendo_cmb_state_name(
+    m_CrescendoOverrideMode[crescendoIdx], crescendoIdx);
+}
 
 void GOSetter::Load(GOConfigReader &cfg) {
   m_OrganController->RegisterSaveableObject(this);
@@ -382,14 +394,20 @@ void GOSetter::Load(GOConfigReader &cfg) {
     m_CrescendoOverrideMode[i] = cfg.ReadBoolean(
       CMBSetting, buffer, WX_OVERRIDE_MODE, false, defaultAddMode);
   }
-  for (unsigned i = 0; i < N_CRESCENDOS * CRESCENDO_STEPS; i++) {
-    m_crescendo.push_back(new GOGeneralCombination(*m_OrganController, true));
-    m_CrescendoExtraSets.emplace_back();
-    buffer.Printf(
-      wxT("SetterCrescendo%d_%03d"),
-      (i / CRESCENDO_STEPS) + 1,
-      (i % CRESCENDO_STEPS) + 1);
-    m_crescendo[i]->Load(cfg, buffer);
+  for (uint8_t crescendoIdx = 0; crescendoIdx < N_CRESCENDOS; crescendoIdx++) {
+    wxString cmbStateName = GetCrescendoCmbStateName(crescendoIdx);
+
+    for (unsigned i = 0; i < CRESCENDO_STEPS; i++) {
+      GOGeneralCombination *pCmb
+        = new GOGeneralCombination(*m_OrganController, true);
+
+      m_crescendo.push_back(pCmb);
+      pCmb->Load(
+        cfg,
+        wxString::Format(
+          wxT("SetterCrescendo%d_%03d"), crescendoIdx + 1, i + 1));
+      pCmb->SetCombinationStateName(cmbStateName);
+    }
   }
 
   m_buttons[ID_SETTER_PREV]->Init(cfg, wxT("SetterPrev"), _("Previous"));
@@ -459,7 +477,7 @@ void GOSetter::Load(GOConfigReader &cfg) {
   m_buttons[ID_SETTER_FILE_EXIT]->Init(
     cfg, wxT("ExitGO"), _("Exit GrandOrgue"));
 
-  m_swell.Init(cfg, wxT("SetterSwell"), _("Crescendo"), 0);
+  m_CrescendoCtrl.Init(cfg, wxT("SetterSwell"), _("Crescendo"), 0);
 
   m_PosDisplay.Init(cfg, wxT("SetterCurrentPosition"), _("sequencer position"));
   m_BankDisplay.Init(cfg, wxT("SetterGeneralBank"), _("general bank"));
@@ -539,8 +557,9 @@ void GOSetter::NotifyCmbChanged() {
   m_OrganController->SetOrganModified();
 }
 
-void GOSetter::NotifyCmbPushed(bool isChanged) {
-  if (isChanged && m_state.m_IsActive && !m_state.m_IsModified) {
+void GOSetter::NotifyCmbPushed(bool isChanged, bool isForceSet) {
+  if (
+    isChanged && (m_state.m_IsActive || isForceSet) && !m_state.m_IsModified) {
     m_state.m_IsModified = true;
     // light the save button if the last loaded combination file  is displayed
     if (
@@ -677,9 +696,17 @@ void GOSetter::FromYaml(const YAML::Node &yamlNode) {
       >> *m_framegeneral[i];
 }
 
-void GOSetter::ButtonStateChanged(int id, bool newState) {
-  GOCombination::ExtraElementsSet elementSet;
+bool GOSetter::CopyFrameGenerals(
+  unsigned fromIdx, unsigned toIdx, bool changedBefore) {
+  const GOGeneralCombination *pNewCmb = m_framegeneral[fromIdx];
+  GOGeneralCombination *pOldCmb = m_framegeneral[toIdx];
+  bool changed = (changedBefore || !pOldCmb->IsEmpty() || !pNewCmb->IsEmpty());
 
+  pOldCmb->Copy(pNewCmb);
+  return changed;
+}
+
+void GOSetter::ButtonStateChanged(int id, bool newState) {
   switch (id) {
 
   case ID_SETTER_REFRESH_FILES:
@@ -753,18 +780,25 @@ void GOSetter::ButtonStateChanged(int id, bool newState) {
   case ID_SETTER_CURRENT:
     SetPosition(m_pos);
     break;
-  case ID_SETTER_DELETE:
+  case ID_SETTER_DELETE: {
+    bool changed = false;
+
     for (unsigned j = m_pos; j < m_framegeneral.size() - 1; j++)
-      m_framegeneral[j]->Copy(m_framegeneral[j + 1]);
+      changed = CopyFrameGenerals(j + 1, j, changed);
     UpdateAllButtonsLight(nullptr, -1);
-    NotifyCmbChanged();
+    NotifyCmbPushed(changed, true);
     break;
-  case ID_SETTER_INSERT:
+  }
+  case ID_SETTER_INSERT: {
+    bool changed = false;
+
     for (unsigned j = m_framegeneral.size() - 1; j > m_pos; j--)
-      m_framegeneral[j]->Copy(m_framegeneral[j - 1]);
+      changed = CopyFrameGenerals(j - 1, j, changed);
+    UpdateAllButtonsLight(nullptr, -1);
     SetPosition(m_pos);
-    NotifyCmbChanged();
+    NotifyCmbPushed(changed, true);
     break;
+  }
   case ID_SETTER_L0:
   case ID_SETTER_L1:
   case ID_SETTER_L2:
@@ -868,10 +902,16 @@ void GOSetter::ButtonStateChanged(int id, bool newState) {
       nullptr);
     break;
 
-  case ID_SETTER_CRESCENDO_OVERRIDE:
-    m_CrescendoOverrideMode[m_crescendobank] = newState;
-    m_buttons[ID_SETTER_CRESCENDO_OVERRIDE]->Display(newState);
+  case ID_SETTER_CRESCENDO_OVERRIDE: {
+    wxString cmbStateName = crescendo_cmb_state_name(newState, m_crescendobank);
 
+    m_CrescendoOverrideMode[m_crescendobank] = newState;
+    for (unsigned i = 0; i < CRESCENDO_STEPS; i++)
+      m_crescendo[N_CRESCENDOS * m_crescendobank + i]->SetCombinationStateName(
+        cmbStateName);
+    m_buttons[ID_SETTER_CRESCENDO_OVERRIDE]->Display(newState);
+    break;
+  }
   case ID_SETTER_PITCH_M1:
     m_OrganController->GetRootPipeConfigNode().ModifyManualTuning(-1);
     m_OrganController->GetRootPipeConfigNode().ModifyAutoTuningCorrection(-1);
@@ -996,7 +1036,9 @@ void GOSetter::OnCombinationsSaved(const wxString &yamlFile) {
 
 void GOSetter::Update() {}
 
-void GOSetter::SetterActive(bool on) { m_buttons[ID_SETTER_SET]->Set(on); }
+void GOSetter::SetterActive(bool on) {
+  m_buttons[ID_SETTER_SET]->SetButtonState(on);
+}
 
 void GOSetter::ToggleSetter() { m_buttons[ID_SETTER_SET]->Push(); }
 
@@ -1020,13 +1062,10 @@ void GOSetter::UpdateAllSetsButtonsLight(
 
 void GOSetter::PushGeneral(
   GOGeneralCombination &cmb, GOButtonControl *pButtonToLight) {
-  GOCombination::ExtraElementsSet elementSet;
-  const GOCombination::ExtraElementsSet *pExtraSet
-    = GetCrescendoAddSet(elementSet);
-
-  NotifyCmbPushed(cmb.Push(m_state, pExtraSet));
-  if (!pExtraSet) { // Otherwise the crescendo in add mode:
-                    // not to switch off combination buttons
+  NotifyCmbPushed(cmb.Push(m_state));
+  if (pButtonToLight || IsCurrentCrescendoOverride()) {
+    // Otherwise the crescendo in add mode: not to switch off combination
+    // buttons
     UpdateAllSetsButtonsLight(pButtonToLight, -1);
   }
 }
@@ -1037,12 +1076,8 @@ void GOSetter::PushDivisional(
   unsigned cmbManual,
   GOButtonControl *pButtonToLight) {
   if (cmbManual == startManual || !m_state.m_IsActive) {
-    GOCombination::ExtraElementsSet elementSet;
-    const GOCombination::ExtraElementsSet *pExtraSet
-      = GetCrescendoAddSet(elementSet);
-
-    NotifyCmbPushed(cmb.Push(m_state, pExtraSet));
-    if (!pExtraSet)
+    NotifyCmbPushed(cmb.Push(m_state));
+    if (pButtonToLight || IsCurrentCrescendoOverride())
       UpdateAllSetsButtonsLight(pButtonToLight, cmbManual);
   }
 }
@@ -1072,18 +1107,6 @@ void GOSetter::SetCrescendoType(unsigned no) {
     m_CrescendoOverrideMode[m_crescendobank]);
 }
 
-const GOCombination::ExtraElementsSet *GOSetter::GetCrescendoAddSet(
-  GOCombination::ExtraElementsSet &elementSet) {
-  const GOCombination::ExtraElementsSet *pResElementSet = nullptr;
-
-  if (!m_CrescendoOverrideMode[m_crescendobank]) {
-    m_crescendo[m_crescendopos + m_crescendobank * CRESCENDO_STEPS]
-      ->GetEnabledElements(elementSet);
-    pResElementSet = &elementSet;
-  }
-  return pResElementSet;
-}
-
 void GOSetter::UpdatePosition(int pos) {
   if (pos != (int)m_pos)
     SetPosition(pos);
@@ -1129,14 +1152,8 @@ void GOSetter::Crescendo(int newpos, bool force) {
     const unsigned oldIdx = m_crescendopos + m_crescendobank * CRESCENDO_STEPS;
     const unsigned newIdx = oldIdx + 1;
 
-    if (crescendoAddMode)
-      m_crescendo[oldIdx]->GetExtraSetState(m_CrescendoExtraSets[oldIdx]);
-    else
-      m_CrescendoExtraSets[oldIdx].clear();
     ++m_crescendopos;
-    changed = changed
-      || m_crescendo[newIdx]->Push(
-        m_state, crescendoAddMode ? &m_CrescendoExtraSets[oldIdx] : nullptr);
+    changed = changed || m_crescendo[newIdx]->Push(m_state);
   }
 
   while (pos < m_crescendopos) {
@@ -1144,9 +1161,7 @@ void GOSetter::Crescendo(int newpos, bool force) {
 
     const unsigned newIdx = m_crescendopos + m_crescendobank * CRESCENDO_STEPS;
 
-    changed = changed
-      || m_crescendo[newIdx]->Push(
-        m_state, crescendoAddMode ? &m_CrescendoExtraSets[newIdx] : nullptr);
+    changed = changed || m_crescendo[newIdx]->Push(m_state);
   }
   // switch combination buttons off in the crescendo override mode
   if (changed && !crescendoAddMode)
@@ -1159,8 +1174,8 @@ void GOSetter::Crescendo(int newpos, bool force) {
 }
 
 void GOSetter::ControlChanged(GOControl *control) {
-  if (control == &m_swell)
-    Crescendo(m_swell.GetValue() * CRESCENDO_STEPS / 128);
+  if (control == &m_CrescendoCtrl)
+    Crescendo(m_CrescendoCtrl.GetValue() * CRESCENDO_STEPS / 128);
 }
 
 void GOSetter::UpdateTranspose() {
@@ -1186,7 +1201,7 @@ void GOSetter::UpdateModified(bool modified) {
 
 GOEnclosure *GOSetter::GetEnclosure(const wxString &name, bool is_panel) {
   if (name == wxT("Swell"))
-    return &m_swell;
+    return &m_CrescendoCtrl;
 
   return NULL;
 }
